/**
 * Main application configuration object.
 * Aggregates settings from environment variables and package.json.
 */
export declare const config: {
    /** The name of the MCP server, derived from package.json. */
    mcpServerName: string;
    /** The version of the MCP server, derived from package.json. */
    mcpServerVersion: string;
    /** Logging level for the application (e.g., "debug", "info", "warn", "error"). Defaults to "info". */
    logLevel: string;
    /** The runtime environment (e.g., "development", "production"). Defaults to "development". */
    environment: string;
    /** Security-related configurations. */
    security: {
        /** Indicates if authentication is required for server operations. */
        authRequired: boolean;
    };
    /** Perplexity API Key, loaded from environment variables. */
    perplexityApiKey: string;
    /** Default Perplexity model to use for search-like tools. */
    perplexityDefaultModel: string;
    /** Default Perplexity search context size ('low', 'medium', 'high'). */
    perplexityDefaultSearchContext: "low" | "medium" | "high";
};
/**
 * The configured logging level for the application.
 * Exported separately for convenience (e.g., logger initialization).
 * @type {string}
 */
export declare const logLevel: string;
/**
 * The configured runtime environment for the application.
 * Exported separately for convenience.
 * @type {string}
 */
export declare const environment: string;
